# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`pg_profile`](#pg_profile): This is the interface class for this profile. This may only contain parameters and no actual configuration enforcing
* [`pg_profile::database`](#pg_profiledatabase): ## Overview
* [`pg_profile::database::cis_controls`](#pg_profiledatabasecis_controls): This class contains the actual code securing the database.
* [`pg_profile::database::db_definition`](#pg_profiledatabasedb_definition): This class contains the actual database definition using the `pg_database` type.
* [`pg_profile::database::db_init`](#pg_profiledatabasedb_init): This class implements the steps to initialize the database for the foirst time.
* [`pg_profile::database::db_parameters`](#pg_profiledatabasedb_parameters): This class contains the definition for all the database parameters.
* [`pg_profile::database::db_records`](#pg_profiledatabasedb_records): This class contains the definition for all the database records.
* [`pg_profile::database::db_roles`](#pg_profiledatabasedb_roles): This class contains the definition for all the database roles (users) you'd like on your system.
* [`pg_profile::database::db_schemas`](#pg_profiledatabasedb_schemas): This class contains the definition for all the database schemas.
* [`pg_profile::database::db_software`](#pg_profiledatabasedb_software): This class contains the definition of the Postgres software packages you want to use on this system.
* [`pg_profile::database::db_startup`](#pg_profiledatabasedb_startup): This class contains the definition for the auto startup of Postgres after a system reboot.
* [`pg_profile::database::db_tablespaces`](#pg_profiledatabasedb_tablespaces): This class contains the definition for all the tablespaces you'd like on your system.
* [`pg_profile::database::em_license`](#pg_profiledatabaseem_license): This class will deploy the Enterprise Modules license.
* [`pg_profile::secured_database`](#pg_profilesecured_database): This is a highly customizable Puppet profile class to define an Secured Postgres database on your system.

### Functions

* [`set_param`](#set_param): See the file "LICENSE" for the full license governing this code.  Returns the value for requested parameter. Currently supported parameters: 

## Classes

### <a name="pg_profile"></a>`pg_profile`

This is the interface class for this profile. This may only contain parameters and no actual configuration enforcing

#### Parameters

The following parameters are available in the `pg_profile` class:

* [`version`](#version)
* [`os_user`](#os_user)
* [`os_group`](#os_group)
* [`db_name`](#db_name)

##### <a name="version"></a>`version`

Data type: `String[1]`



##### <a name="os_user"></a>`os_user`

Data type: `String[1]`



##### <a name="os_group"></a>`os_group`

Data type: `String[1]`



##### <a name="db_name"></a>`db_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

### <a name="pg_profiledatabase"></a>`pg_profile::database`

pg_profile::database

This is a highly customizable Puppet profile class to define an Postgres database on your system. In it's core just adding:

```
contain ::pg_profile::database
```

Is enough to get an Postgres database running on your system.

But sometimes you have specific uses cases that are not handled well by the standard classes. This profile class allows you to add your own code to the execution.

## Stages

Defining and starting an Postgres database on you system goes through several steps:

- em_license          ( Manage Enterprise Modules Licenses)
- sysctl              ( Setup any sysctl parameters)
- limits              ( Setup any security limits)
- groups_and_users    ( Setup required groups and users)
- packages            ( Setup any required after_packages)
- firewall            ( Setup the firewall)
- db_software         ( Install the postgres software)
- db_init             ( Take care of initial database stup)
- db_startup          ( Manage starting the database)
- db_roles            ( Ensure required Postgres database roles)
- db_definition       ( Ensure required Postgress databases)
- db_parameters       ( Ensure required Postgres database settings)
- db_tablespaces      ( Ensure needed tablespaces)
- db_schemas          ( Ensure needed database schema's)
- db_records          ( Ensure required database records (for settings))

All these steps have a default implementation. This implementation is suitable to get started with. These classed all have parameters you can customize through hiera values. The defaults are specified in the module's `data/default.yaml` file.

## before classes

But sometimes this is not enough and you would like to add some extra definitions, you can, for example, add a Puppet class to be executed after the `systctl` stage is done and before the `limits` is done. You can do this by adding the next line to your yaml data:

```yaml
pg_profile::database::before_sysctl:   my_profile::my_extra_class
```

## after classes

You can do the same when you want to add code after one of the stage classes:

```yaml
pg_profile::database::after_sysctl:   my_profile::my_extra_class
```

## Skipping

Sometimes organisation use different modules and mechanisms to implement a feature and you want to skip the class:

```yaml
pg_profile::database::sysctl:   skip
```

## Replacing

Or provide your own implementation:

```yaml
pg_profile::database::sysctl:   my_profile::my_own_implementation
```

This mechanism can be used for all named stages and makes it easy to move from an easy setup with a running standard database to a fully customized setup using a lot of your own classes plugged in.

Look at the description of the stages and their properties.

At this level you can also customize some generic settings. Check the settings for:

- `version`

Here is an example on how you can do this:

```puppet

class {'pg_profile::database':
  version => '13',
}

```


<!--
 -->

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database` class:

* [`before_em_license`](#before_em_license)
* [`before_sysctl`](#before_sysctl)
* [`before_limits`](#before_limits)
* [`before_groups_and_users`](#before_groups_and_users)
* [`before_packages`](#before_packages)
* [`before_firewall`](#before_firewall)
* [`before_db_software`](#before_db_software)
* [`before_db_init`](#before_db_init)
* [`before_db_startup`](#before_db_startup)
* [`before_db_roles`](#before_db_roles)
* [`before_db_definition`](#before_db_definition)
* [`before_db_parameters`](#before_db_parameters)
* [`before_db_tablespaces`](#before_db_tablespaces)
* [`before_db_schemas`](#before_db_schemas)
* [`before_db_records`](#before_db_records)
* [`em_license`](#em_license)
* [`sysctl`](#sysctl)
* [`limits`](#limits)
* [`groups_and_users`](#groups_and_users)
* [`packages`](#packages)
* [`firewall`](#firewall)
* [`db_software`](#db_software)
* [`db_init`](#db_init)
* [`db_startup`](#db_startup)
* [`db_roles`](#db_roles)
* [`db_definition`](#db_definition)
* [`db_parameters`](#db_parameters)
* [`db_tablespaces`](#db_tablespaces)
* [`db_schemas`](#db_schemas)
* [`db_records`](#db_records)
* [`after_em_license`](#after_em_license)
* [`after_sysctl`](#after_sysctl)
* [`after_limits`](#after_limits)
* [`after_groups_and_users`](#after_groups_and_users)
* [`after_packages`](#after_packages)
* [`after_firewall`](#after_firewall)
* [`after_db_software`](#after_db_software)
* [`after_db_init`](#after_db_init)
* [`after_db_startup`](#after_db_startup)
* [`after_db_roles`](#after_db_roles)
* [`after_db_definition`](#after_db_definition)
* [`after_db_parameters`](#after_db_parameters)
* [`after_db_tablespaces`](#after_db_tablespaces)
* [`after_db_schemas`](#after_db_schemas)
* [`after_db_records`](#after_db_records)

##### <a name="before_em_license"></a>`before_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_em_license:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_sysctl"></a>`before_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_sysctl:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_limits"></a>`before_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_limits:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_groups_and_users"></a>`before_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_packages"></a>`before_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_packages:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_firewall"></a>`before_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_firewall:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_software"></a>`before_db_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_software` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_software:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_init"></a>`before_db_init`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_init` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_init:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_startup"></a>`before_db_startup`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_startup` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_startup:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_roles"></a>`before_db_roles`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_users` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_users:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_definition"></a>`before_db_definition`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_definition` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_definition:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_parameters"></a>`before_db_parameters`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_parameters` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_parameters:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_tablespaces"></a>`before_db_tablespaces`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_tablespaces` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_tablespaces:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_schemas"></a>`before_db_schemas`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_schemas` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_schemas:  my_module::my_class
```

Default value: ``undef``

##### <a name="before_db_records"></a>`before_db_records`

Data type: `Optional[String]`

The name of the class you want to execute directly **before** the `db_records` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::before_db_records:  my_module::my_class
```

Default value: ``undef``

##### <a name="em_license"></a>`em_license`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `em_license`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::em_license:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::em_license:  skip
```

Default value: ``undef``

##### <a name="sysctl"></a>`sysctl`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `sysctl`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_definition:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_definition:  skip
```

Default value: ``undef``

##### <a name="limits"></a>`limits`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `limits`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::limits:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::limits:  skip
```

Default value: ``undef``

##### <a name="groups_and_users"></a>`groups_and_users`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `groups_and_users`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::groups_and_users:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::groups_and_users:  skip
```

Default value: ``undef``

##### <a name="packages"></a>`packages`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `packages`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::packages:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::packages:  skip
```

Default value: ``undef``

##### <a name="firewall"></a>`firewall`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `firewall`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::firewall:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::firewall:  skip
```

Default value: ``undef``

##### <a name="db_software"></a>`db_software`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_software`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_software:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_software:  skip
```

Default value: ``undef``

##### <a name="db_init"></a>`db_init`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_init`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_init:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_init:  skip
```

Default value: ``undef``

##### <a name="db_startup"></a>`db_startup`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_startup`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_startup:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_startup:  skip
```

Default value: ``undef``

##### <a name="db_roles"></a>`db_roles`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_roles`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_roles:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_roles:  skip
```

Default value: ``undef``

##### <a name="db_definition"></a>`db_definition`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_definition`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_definition:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_definition:  skip
```

Default value: ``undef``

##### <a name="db_parameters"></a>`db_parameters`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_parameters`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_parameters:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_parameters:  skip
```

Default value: ``undef``

##### <a name="db_tablespaces"></a>`db_tablespaces`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_tablespaces`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_tablespaces:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_tablespaces:  skip
```

Default value: ``undef``

##### <a name="db_schemas"></a>`db_schemas`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_schemas`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_schemas:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_schemas:  skip
```

Default value: ``undef``

##### <a name="db_records"></a>`db_records`

Data type: `Optional[String]`

Use this value if you want to skip or use your own class for step `db_records`.
## Use your own class
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_records:  my_module::my_class
```
## Skip
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::db_records:  skip
```

Default value: ``undef``

##### <a name="after_em_license"></a>`after_em_license`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `em_license` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_em_license:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_sysctl"></a>`after_sysctl`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `sysctl` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_sysctl:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_limits"></a>`after_limits`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `limits` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_limits:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_groups_and_users"></a>`after_groups_and_users`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `groups_and_users` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_groups_and_users:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_packages"></a>`after_packages`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `packages` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_packages:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_firewall"></a>`after_firewall`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `firewall` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_firewall:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_software"></a>`after_db_software`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_software` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_software:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_init"></a>`after_db_init`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_init` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_init:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_startup"></a>`after_db_startup`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_startup` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_startup:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_roles"></a>`after_db_roles`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_users` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_users:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_definition"></a>`after_db_definition`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_definition` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_definition:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_parameters"></a>`after_db_parameters`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_parameters` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_parameters:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_tablespaces"></a>`after_db_tablespaces`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_tablespaces` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_tablespaces:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_schemas"></a>`after_db_schemas`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_schemas` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_schemas:  my_module::my_class
```

Default value: ``undef``

##### <a name="after_db_records"></a>`after_db_records`

Data type: `Optional[String]`

The name of the class you want to execute directly **after** the `db_records` class.
You can use hiera to set this value. Here is an example:
```yaml
pg_profile::database::after_db_records:  my_module::my_class
```

Default value: ``undef``

### <a name="pg_profiledatabasecis_controls"></a>`pg_profile::database::cis_controls`

pg_profile::database::cis_controls

Here you can customize the security by specifying the CIS rules you *don't* want to apply.


When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::secured_database](./secured_database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::cis_controls` class:

* [`dbname`](#dbname)
* [`product_version`](#product_version)
* [`doc_version`](#doc_version)
* [`skip_list`](#skip_list)

##### <a name="dbname"></a>`dbname`

Data type: `String[1]`

The name of the database you want to secure

##### <a name="product_version"></a>`product_version`

Data type: `Optional[String[1]]`

The database version of the CIS benchmark you want to apply.
Although not very logical, you **can** apply an older (or newer) database version to your database.
If you also don't specify a `product_version`, Puppet will detect the version of Postgres running and use this to determine the `product_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Postgres version is. In that case, the ora_cis defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Postgres for specified sid is available.

##### <a name="doc_version"></a>`doc_version`

Data type: `Optional[String[1]]`

The version of the CIS benchmark you want to apply to your database.
When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `db_version`.

##### <a name="skip_list"></a>`skip_list`

Data type: `Optional[Array[String[1]]]`

This is the list of controls that you want to skip.
By default this value is empty, meaning `ora_cis` will apply **ALL** controls. You must specify the name of the control.

### <a name="pg_profiledatabasedb_definition"></a>`pg_profile::database::db_definition`

pg_profile::database::db_definition

Here you add additiona databases to your system.

When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::db_definition` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

A list of database profiles to define.
The default value is: `{}`
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your database, to override this class and  add your own puppet implementation. This is much better maintainable and adds more consistency.

### <a name="pg_profiledatabasedb_init"></a>`pg_profile::database::db_init`

pg_profile::database::db_init

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::db_init` class:

* [`data_dirs`](#data_dirs)
* [`log_dirs`](#log_dirs)
* [`data_dir`](#data_dir)
* [`log_dir`](#log_dir)

##### <a name="data_dirs"></a>`data_dirs`

Data type: `Array[Stdlib::Absolutepath]`

An array of directories for which Puppet will set the properties correct to use them as data directories.

##### <a name="log_dirs"></a>`log_dirs`

Data type: `Array[Stdlib::Absolutepath]`

An array of directories for which Puppet will set the properties correct to use them as log directories.

##### <a name="data_dir"></a>`data_dir`

Data type: `Stdlib::Absolutepath`

The directory Postgres will use fto store the data files.

##### <a name="log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

The directory Postgres will use for after image logging.

### <a name="pg_profiledatabasedb_parameters"></a>`pg_profile::database::db_parameters`

pg_profile::database::db_parameters

When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::db_parameters` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

A list of database properties to define.
The default value is: `{}`
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your database, to override this class and  add your own puppet implementation. This is much better maintainable and adds more consistency.

### <a name="pg_profiledatabasedb_records"></a>`pg_profile::database::db_records`

pg_profile::database::db_records

When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::db_records` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

A Hash of the database records you want to add to the system.
The default value is `{}`

### <a name="pg_profiledatabasedb_roles"></a>`pg_profile::database::db_roles`

pg_profile::database::db_roles

When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::db_roles` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

A list of database profiles to define.
The default value is: `{}`
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your roles, to override this class and  add your own puppet implementation. This is much better maintainable and adds more consistency.

### <a name="pg_profiledatabasedb_schemas"></a>`pg_profile::database::db_schemas`

pg_profile::database::db_schemas

When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::db_schemas` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

A Hash of the database schemas you want to add to the system.
The default value is `{}`

### <a name="pg_profiledatabasedb_software"></a>`pg_profile::database::db_software`

pg_profile::database::db_software

When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::db_software` class:

* [`proxy`](#proxy)
* [`base_url`](#base_url)
* [`install_contrib`](#install_contrib)
* [`install_devel`](#install_devel)
* [`install_docs`](#install_docs)
* [`install_llvmjit`](#install_llvmjit)
* [`install_odbc`](#install_odbc)
* [`install_plperl`](#install_plperl)
* [`install_plpython3`](#install_plpython3)
* [`install_pltcl`](#install_pltcl)
* [`install_test`](#install_test)

##### <a name="proxy"></a>`proxy`

Data type: `Optional[String[1]]`

The url of a proxy to use for accessing the Purgres yum server

##### <a name="base_url"></a>`base_url`

Data type: `String[1]`

The base URL for the Postgres yum channel.

##### <a name="install_contrib"></a>`install_contrib`

Data type: `Boolean`

If you want to install the Postgres `contrib` package, set this value to `true`.
The default value is `false`.

##### <a name="install_devel"></a>`install_devel`

Data type: `Boolean`

If you want to install the Postgres `devel` package, set this value to `true`.
The default value is `false`.

##### <a name="install_docs"></a>`install_docs`

Data type: `Boolean`

If you want to install the Postgres `docs` package, set this value to `true`.
The default value is `false`.

##### <a name="install_llvmjit"></a>`install_llvmjit`

Data type: `Boolean`

If you want to install the Postgres `llvmjit` package, set this value to `true`.
The default value is `false`.

##### <a name="install_odbc"></a>`install_odbc`

Data type: `Boolean`

If you want to install the Postgres `odbc` package, set this value to `true`.
The default value is `false`.

##### <a name="install_plperl"></a>`install_plperl`

Data type: `Boolean`

If you want to install the Postgres `plperl` package, set this value to `true`.
The default value is `false`.

##### <a name="install_plpython3"></a>`install_plpython3`

Data type: `Boolean`

If you want to install the Postgres `plpython3` package, set this value to `true`.
The default value is `false`.

##### <a name="install_pltcl"></a>`install_pltcl`

Data type: `Boolean`

If you want to install the Postgres `pltcl` package, set this value to `true`.
The default value is `false`.

##### <a name="install_test"></a>`install_test`

Data type: `Boolean`

If you want to install the Postgres `test` package, set this value to `true`.
The default value is `false`.

### <a name="pg_profiledatabasedb_startup"></a>`pg_profile::database::db_startup`

pg_profile::database::db_startup

When these customizations aren't enough, you can replace the class with your own class. See [ora_profile::database](./database.html) for an explanation on how to do this.


See the file "LICENSE" for the full license governing this code.

### <a name="pg_profiledatabasedb_tablespaces"></a>`pg_profile::database::db_tablespaces`

pg_profile::database::db_tablespaces

When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.

See the file "LICENSE" for the full license governing this code.

#### Parameters

The following parameters are available in the `pg_profile::database::db_tablespaces` class:

* [`list`](#list)

##### <a name="list"></a>`list`

Data type: `Hash`

A list of database tablespaces to define.
The default value is: `{}`
This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your Postgres tablespaces, to override this class and  add your own puppet implementation. This is much better maintainable
and adds more consistency.

### <a name="pg_profiledatabaseem_license"></a>`pg_profile::database::em_license`

pg_profile::database::em_license

See the file "LICENSE" for the full license governing this code.

### <a name="pg_profilesecured_database"></a>`pg_profile::secured_database`

pg_profile::secured_database

In it's core just adding:

```
contain pg_profile::secured_database
```

Is enough to get a secured Postgres database running on your system.

This profile class is based on the more generic [`pg_profile::database`](./database.html) class, but extends this class with securing the database conforming to the Postgres Center for Internet Security (CIS) rules.


See the file "LICENSE" for the full license governing this code.

## Functions

### <a name="set_param"></a>`set_param`

Type: Ruby 4.x API

See the file "LICENSE" for the full license governing this code.

Returns the value for requested parameter.
Currently supported parameters:
- instance_name
- instance_number
- thread_number

rubocop: disable Metrics/AbcSize
rubocop: disable Metrics/CyclomaticComplexity
rubocop: disable Metrics/PerceivedComplexity
rubocop: disable Metrics/MethodLength

#### `set_param(String $param_name, String $dbname, Optional[Undef] $cluster_nodes)`

The set_param function.

Returns: `String`

##### `param_name`

Data type: `String`



##### `dbname`

Data type: `String`



##### `cluster_nodes`

Data type: `Optional[Undef]`



#### `set_param(String $param_name, String $dbname, Array $cluster_nodes)`

The set_param function.

Returns: `Any`

##### `param_name`

Data type: `String`



##### `dbname`

Data type: `String`



##### `cluster_nodes`

Data type: `Array`



