#
# pg_profile::database::db_tablespaces
#
# @summary This class contains the definition for all the tablespaces you'd like on your system.
# When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.
#
# @param [Hash] list
#    A list of database tablespaces to define.
#    The default value is: `{}`
#    This is a simple way to get started. It is easy to get started, but soon your hiera yaml become a nigtmare. Our advise is when you need to let puppet manage your Postgres tablespaces, to override this class and  add your own puppet implementation. This is much better maintainable
#    and adds more consistency.
#
#
# See the file "LICENSE" for the full license governing this code.
#
class pg_profile::database::db_tablespaces(
  Hash $list,
) inherits pg_profile {

  easy_type::debug_evaluation() # Show local variable on extended debug

  if $list.keys.size > 0 {
    echo {"Ensure Postgres database(s) ${list.keys.join(',')}":
      withpath => false,
    }
  }
  #
  # This is a simple way to get started. It is easy to get started, but
  # soon your hiera yaml becomes a nigtmare. Our advise is when you need
  # to let Puppet manage your Postgres resources, to override this class and 
  # add your own Puppet implementation. This is a much better, more
  # maintainable, and adds more consistency.
  #
  ensure_resources(pg_tablespace, $list)
}
